normalize_path_key

Function normalize_path_key 

pub fn normalize_path_key(raw: &str) -> Option<String>
Normalize a path for use as a map key (ownership manifest, bundle dedup).

Thin wrapper around normalize_artifact_path that returns None on error instead of Err. Callers that want diagnostics should use normalize_artifact_path directly.